@@ -104,19 +104,17 @@ sub _development {
 
   # Filtered stash snapshot
   my $stash = $c->stash;
-  my %snapshot = map { $_ => $stash->{$_} }
+  %{$stash->{snapshot} = {}} = map { $_ => $stash->{$_} }
     grep { !/^mojo\./ and defined $stash->{$_} } keys %$stash;
+  $stash->{exception} = $page eq 'exception' ? $e : undef;
 
   # Render with fallbacks
-  my $mode     = $app->mode;
-  my $renderer = $app->renderer;
-  my $options  = {
-    exception => $page eq 'exception' ? $e : undef,
-    format    => $stash->{format} || $renderer->default_format,
-    handler   => undef,
-    snapshot  => \%snapshot,
-    status    => $page eq 'exception' ? 500 : 404,
-    template  => "$page.$mode"
+  my $mode    = $app->mode;
+  my $options = {
+    format   => $stash->{format} || $app->renderer->default_format,
+    handler  => undef,
+    status   => $page eq 'exception' ? 500 : 404,
+    template => "$page.$mode"
   };
   my $bundled = 'mojo/' . ($mode eq 'development' ? 'debug' : $page);
   return $c if _fallbacks($c, $options, $page, $bundled);
@@ -137,7 +135,7 @@ sub _fallbacks {
 
   # Inline template
   my $stash = $c->stash;
-  return undef unless $stash->{format} eq 'html';
+  return undef unless $options->{format} eq 'html';
   delete @$stash{qw(extends layout)};
   return $c->render_maybe($bundled, %$options, handler => 'ep');
 }
